@@ -2,8 +2,8 @@ from fastapi import Depends
 from strawberry.fastapi import BaseContext
 
 {%- if cookiecutter.enable_redis == "True" %}
-from redis.asyncio import Redis
-from {{cookiecutter.project_name}}.services.redis.dependency import get_redis_connection
+from redis.asyncio import ConnectionPool
+from {{cookiecutter.project_name}}.services.redis.dependency import get_redis_pool
 {%- endif %}
 
 {%- if cookiecutter.enable_rmq == "True" %}
@@ -12,15 +12,18 @@ from aio_pika import Channel
 from {{cookiecutter.project_name}}.services.rabbit.dependencies import get_rmq_channel_pool
 {%- endif %}
 
-
-{%- if cookiecutter.db_info.name != 'none' %}
-from {{cookiecutter.project_name}}.db.dependencies import get_db_session
+{%- if cookiecutter.enable_kafka == "True" %}
+from aiokafka import AIOKafkaProducer
+from {{cookiecutter.project_name}}.services.kafka.dependencies import get_kafka_producer
 {%- endif %}
 
+
 {%- if cookiecutter.orm == "sqlalchemy" %}
 from sqlalchemy.ext.asyncio import AsyncSession
+from {{cookiecutter.project_name}}.db.dependencies import get_db_session
 {%- elif cookiecutter.orm == "psycopg" %}
-from psycopg import AsyncConnection
+from psycopg_pool import AsyncConnectionPool
+from {{cookiecutter.project_name}}.db.dependencies import get_db_pool
 {%- endif %}
 
 
@@ -30,7 +33,7 @@ class Context(BaseContext):
     def __init__(
         self,
         {%- if cookiecutter.enable_redis == "True" %}
-        redis: Redis = Depends(get_redis_connection),
+        redis_pool: ConnectionPool = Depends(get_redis_pool),
         {%- endif %}
         {%- if cookiecutter.enable_rmq == "True" %}
         rabbit: Pool[Channel] = Depends(get_rmq_channel_pool),
@@ -38,18 +41,27 @@ class Context(BaseContext):
         {%- if cookiecutter.orm == "sqlalchemy" %}
         db_connection: AsyncSession = Depends(get_db_session),
         {%- elif cookiecutter.orm == "psycopg" %}
-        db_connection: AsyncConnection[Any] = Depends(get_db_session),
+        db_pool: AsyncConnectionPool = Depends(get_db_pool),
+        {%- endif %}
+        {%- if cookiecutter.enable_kafka == "True" %}
+        kafka_producer: AIOKafkaProducer = Depends(get_kafka_producer),
         {%- endif %}
     ) -> None:
         {%- if cookiecutter.enable_redis == "True" %}
-        self.redis = redis
+        self.redis_pool = redis_pool
         {%- endif %}
         {%- if cookiecutter.enable_rmq == "True" %}
         self.rabbit = rabbit
         {%- endif %}
-        {%- if cookiecutter.orm in ["sqlalchemy", "psycopg"] %}
+        {%- if cookiecutter.orm  == "sqlalchemy" %}
         self.db_connection = db_connection
         {%- endif %}
+        {%- if cookiecutter.orm == "psycopg" %}
+        self.db_pool = db_pool
+        {%- endif %}
+        {%- if cookiecutter.enable_kafka == "True" %}
+        self.kafka_producer = kafka_producer
+        {%- endif %}
         pass  # noqa: WPS420
 
 
